<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'pleased_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery','pleased-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'pleased-pro' ),
	'panel'             => 'pleased_pro_front_page_panel',
) );

// Gallery content enable control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'pleased_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Pleased_Pro_Switch_Control( $wp_customize, 'pleased_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'pleased-pro' ),
	'section'           => 'pleased_pro_gallery_section',
	'on_off_label' 		=> pleased_pro_switch_options(),
) ) );

// Gallery content type control and setting
$wp_customize->add_setting( 'pleased_pro_theme_options[gallery_content_type]', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback' => 'pleased_pro_sanitize_select',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[gallery_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pleased-pro' ),
	'section'           => 'pleased_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'pleased_pro_is_gallery_section_enable',
	'choices'			=> pleased_pro_gallery_content_type(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Category_Control( $wp_customize,'pleased_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'pleased-pro' ),
	'description'     => esc_html__( 'Note: Press Ctrl and Click on multiple categories to select. Only the Posts that has featured image will be shown from selected categories will be shown.', 'pleased-pro' ),
	'section'           => 'pleased_pro_gallery_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_gallery_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[gallery_content_trip_types]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Category_Control( $wp_customize,'pleased_pro_theme_options[gallery_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'pleased-pro' ),
	'description'     => esc_html__( 'Note: Press Ctrl and Click on multiple categories to select. Only the Posts that has featured image will be shown from selected categories will be shown.', 'pleased-pro' ),
	'section'           => 'pleased_pro_gallery_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_gallery_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[gallery_content_activity]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Category_Control( $wp_customize,'pleased_pro_theme_options[gallery_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'pleased-pro' ),
	'description'     => esc_html__( 'Note: Press Ctrl and Click on multiple categories to select. Only the Posts that has featured image will be shown from selected categories will be shown.', 'pleased-pro' ),
	'section'           => 'pleased_pro_gallery_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_gallery_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'pleased_pro_theme_options[gallery_content_destination]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_integers',
) ) ;

$wp_customize->add_control( new Pleased_Pro_Dropdown_Category_Control( $wp_customize,'pleased_pro_theme_options[gallery_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'pleased-pro' ),
	'description'     => esc_html__( 'Note: Press Ctrl and Click on multiple categories to select. Only the Posts that has featured image will be shown from selected categories will be shown.', 'pleased-pro' ),
	'section'           => 'pleased_pro_gallery_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'pleased_pro_is_gallery_section_content_destination_enable'
) ) );

// banner image setting and control.
$wp_customize->add_setting( 'pleased_pro_theme_options[gallery_background_image]', array(
	'sanitize_callback' => 'pleased_pro_sanitize_image',
	'default'          	=> $options['gallery_background_image'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pleased_pro_theme_options[gallery_background_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'pleased-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'pleased-pro' ), 1920, 525 ),
		'section'     		=> 'pleased_pro_gallery_section',
		'active_callback'	=> 'pleased_pro_is_gallery_section_enable',
) ) );

// gallery title setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[gallery_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[gallery_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_gallery_section',
	'active_callback' 	=> 'pleased_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'pleased_pro_theme_options[gallery_btn_label]', array(
		'selector'            => '#gallery .gallery-collection .wrapper a.btn-primary',
		'settings'            => 'pleased_pro_theme_options[gallery_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'pleased_pro_gallery_btn_label_partial',
    ) );
}

// gallery btn url setting and control
$wp_customize->add_setting( 'pleased_pro_theme_options[gallery_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'pleased_pro_theme_options[gallery_btn_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'pleased-pro' ),
	'section'        	=> 'pleased_pro_gallery_section',
	'active_callback' 	=> 'pleased_pro_is_gallery_section_enable',
	'type'				=> 'url',
) );