<?php
/**
 * Banner section
 *
 * This is the template for the content of banner section
 *
 * @package Theme Palace
 * @subpackage Pleased Pro
 * @since Pleased Pro 1.0.0
 */
if ( ! function_exists( 'pleased_pro_add_banner_section' ) ) :
    /**
    * Add banner section
    *
    *@since Pleased Pro 1.0.0
    */
    function pleased_pro_add_banner_section() {
    	$options = pleased_pro_get_theme_options();
        // Check if banner is enabled on frontpage
        $banner_enable = apply_filters( 'pleased_pro_section_status', true, 'banner_section_enable' );

        if ( true !== $banner_enable ) {
            return false;
        }
        // Get banner section details
        $section_details = array();
        $section_details = apply_filters( 'pleased_pro_filter_banner_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render banner section now.
        pleased_pro_render_banner_section( $section_details );
    }
endif;

if ( ! function_exists( 'pleased_pro_get_banner_section_details' ) ) :
    /**
    * banner section details.
    *
    * @since Pleased Pro 1.0.0
    * @param array $input banner section details.
    */
    function pleased_pro_get_banner_section_details( $input ) {
        $options = pleased_pro_get_theme_options();

        // Content type.
        $banner_content_type  = $options['banner_content_type'];
        
        $content = array();
        switch ( $banner_content_type ) {
        	
            case 'page':
                $page_id = ! empty( $options['banner_content_page'] ) ? $options['banner_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['banner_content_post'] ) ? $options['banner_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            case 'custom':
                $custom['title']      = ! empty( $options['banner_title'] ) ? $options['banner_title'] : '';
                $custom['image']      = ! empty( $options['banner_image'] ) ? $options['banner_image'] : '';
                $custom['url']        = ! empty( $options['banner_btn_url'] ) ? $options['banner_btn_url'] : get_template_directory_uri() . '/assets/uploads/header-image.jpg';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'trip':

                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $post_id = ! empty( $options['banner_content_trip'] ) ? $options['banner_content_trip'] : '';
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            default:
            break;
        }

        if ( 'custom' !== $banner_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/header-image.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// banner section content details.
add_filter( 'pleased_pro_filter_banner_section_details', 'pleased_pro_get_banner_section_details' );


if ( ! function_exists( 'pleased_pro_render_banner_section' ) ) :
  /**
   * Start banner section
   *
   * @return string banner content
   * @since Pleased Pro 1.0.0
   *
   */
   function pleased_pro_render_banner_section( $content_details = array() ) {
        $options = pleased_pro_get_theme_options();

        $featured_video = ! empty( $options['banner_video_url'] ) ? $options['banner_video_url'] : ''; 

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>

            <div id="header-featured-image">
                <div class="overlay"></div>

                <?php if ( ! empty( $content['image'] ) ) : ?>
                    <div class="wp-custom-header">
                        <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>">
                    </div><!--.wp-custom-header -->
                <?php endif; ?>

                <div class="wrapper">

                    <div class="wp-custom-content">

                        <section class="section-header">
                            <?php if ( ! empty( $options['banner_sub_title'] ) ) : ?>
                                <span class="section-subtitle"><?php echo esc_html( $options['banner_sub_title'] ); ?></span>
                            <?php endif; 

                            if ( ! empty( $content['title'] ) ) : ?>
                                <h2 class="section-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            <?php endif; ?>
                        </section><!-- .section-header -->

                        <?php if ( ! empty( $featured_video ) ) : ?>
                            <button type="button" id="video-button">
                                <svg viewBox="0 0 41.999 41.999" >
                                    <path d="M36.068,20.176l-29-20C6.761-0.035,6.363-0.057,6.035,0.114C5.706,0.287,5.5,0.627,5.5,0.999v40
                                    c0,0.372,0.206,0.713,0.535,0.886c0.146,0.076,0.306,0.114,0.465,0.114c0.199,0,0.397-0.06,0.568-0.177l29-20
                                    c0.271-0.187,0.432-0.494,0.432-0.823S36.338,20.363,36.068,20.176z"/>
                                </svg>
                            </button>

                            <div class="video-popup">
                                <?php 
                                $library_video =  attachment_url_to_postid( $featured_video );

                                if ( 0 !== $library_video ) :
                                    the_widget( 'WP_Widget_Media_Video', $instance = array( 'attachment_id' => absint( $library_video ) ) ); 
                                else :
                                    the_widget( 'WP_Widget_Media_Video', $instance = array( 'url' => esc_url( $featured_video ) ) ); 
                                endif;
                                ?>
                            </div>
                        <?php endif; ?>
                    </div><!-- .wp-custom-content -->
                </div>
            </div><!-- #header-featured-image --> 

            <?php if ( class_exists( 'WP_Travel' ) && ( true === $options['banner_search_filter_enable']) ) : ?>
                <div id="travel-log-front-page-itinerary-search-wrap" class="travel-log-show-partial-edit-shortcut">
                    <section id="section-itinerary-search" class="section-itinerary-search">
                        <div class="wrapper"> 
                            <div class="form-wrapper clear"> 
                                <?php pleased_pro_wptravel_search_form(); ?>
                            </div><!-- .form-wrapper -->
                        </div><!-- .wrapper -->  
                    </section><!-- #section-search -->
                </div><!-- #travel-log -->
            <?php endif; ?>

        <?php endforeach; 
    }
endif;